@@ -1,4 +1,4 @@
-# $Id: emoncms.py 1383 2015-10-31 15:59:53Z mwall $
+# $Id: emoncms.py 1483 2016-04-25 06:53:19Z mwall $
 # Copyright 2013-2014 Matthew Wall
 
 """
@@ -64,7 +64,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.13"
+VERSION = "0.14"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -86,7 +86,7 @@ def _obfuscate(s):
     return ('X'*(len(s)-4) + s[-4:])
 
 def _compat(d, old_label, new_label):
-    if d.has_key(old_label) and not d.has_key(new_label):
+    if old_label in d and not new_label in d:
         d.setdefault(new_label, d[old_label])
         d.pop(old_label)
 
@@ -184,11 +184,19 @@ class EmonCMS(weewx.restx.StdRESTbase):
         if usn is not None:
             site_dict['unit_system'] = weewx.units.unit_constants[usn]
 
-        if config_dict['StdRESTful']['EmonCMS'].has_key('inputs'):
+        if 'inputs' in config_dict['StdRESTful']['EmonCMS']:
             site_dict['inputs'] = dict(config_dict['StdRESTful']['EmonCMS']['inputs'])
 
-        site_dict['manager_dict'] = weewx.manager.get_manager_dict(
-            config_dict['DataBindings'],config_dict['Databases'],'wx_binding')
+        # if we are supposed to augment the record with data from weather
+        # tables, then get the manager dict to do it.  there may be no weather
+        # tables, so be prepared to fail.
+        try:
+            if site_dict.get('augment_record'):
+                _manager_dict = weewx.manager.get_manager_dict_from_config(
+                    config_dict, 'wx_binding')
+                site_dict['manager_dict'] = _manager_dict
+        except weewx.UnknownBinding:
+            pass
 
         self.archive_queue = Queue.Queue()
         self.archive_thread = EmonCMSThread(self.archive_queue, **site_dict)
@@ -211,10 +219,11 @@ class EmonCMSThread(weewx.restx.RESTThread):
 
     _DEFAULT_SERVER_URL = 'http://emoncms.org/input/post.json'
 
-    def __init__(self, queue, token, manager_dict,
+    def __init__(self, queue, token,
                  prefix=None, node=None, unit_system=None, augment_record=True,
-                 inputs={}, obs_to_upload='all', append_units_label=True,
+                 inputs=dict(), obs_to_upload='all', append_units_label=True,
                  server_url=_DEFAULT_SERVER_URL, skip_upload=False,
+                 manager_dict=None,
                  post_interval=None, max_backlog=sys.maxint, stale=None,
                  log_success=True, log_failure=True,
                  timeout=60, max_tries=3, retry_wait=5):
@@ -242,7 +251,7 @@ class EmonCMSThread(weewx.restx.RESTThread):
         self.templates = dict()
 
     def process_record(self, record, dbm):
-        if self.augment_record:
+        if self.augment_record and dbm:
             record = self.get_record(record, dbm)
         if self.unit_system is not None:
             record = weewx.units.to_std_system(record, self.unit_system)
